@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pause_id;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.005';
+our $VERSION = '1.006';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -35,6 +35,12 @@ Philippe Bruhat (BooK).
 
 =item *
 
+2012-10-01 - v1.006
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.021.
+
+=item *
+
 2012-09-10 - v1.005
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.018.
@@ -163,6 +169,7 @@ AARON
 AARONJJ
 AARONRP
 AARONSCA
+AASPNAS
 AASSAD
 AAU
 AAYARS
@@ -170,6 +177,7 @@ ABALAMA
 ABARCLAY
 ABCABC
 ABCDEFGH
+ABCXYZ
 ABE
 ABEL
 ABELEW
@@ -292,6 +300,7 @@ AERO
 AERTS
 AESOP
 AESPEN
+AFAN
 AFARIS
 AFARIZWAN
 AFERBER
@@ -347,6 +356,7 @@ AHOYING
 AIDAN
 AIMASS
 AIMBERT
+AINAME
 AIRWAVE
 AIVATURI
 AIZVORSKI
@@ -404,6 +414,7 @@ ALET
 ALEVENSO
 ALEVIN
 ALEX
+ALEXB
 ALEXBIO
 ALEXBYK
 ALEXD
@@ -587,6 +598,7 @@ ANTHONY
 ANTHONYU
 ANTONESCU
 ANTONFIN
+ANTONIKO
 ANTONY
 ANTRO
 ANUNES
@@ -597,6 +609,7 @@ ANZUHAN
 AOCH
 AOCINAR
 AORR
+AOTERRA
 APALADE
 APARNA
 APATSCHE
@@ -1099,6 +1112,7 @@ BIOPERLML
 BIOPREM
 BIRKETT
 BIRNEY
+BIRRIE
 BISHOYH
 BISSCUITT
 BITJAM
@@ -1139,6 +1153,7 @@ BLACKAVAR
 BLACKHAWK
 BLACKJ
 BLACKSTAR
+BLACKWIND
 BLADE
 BLAIR
 BLAIZER
@@ -1146,6 +1161,7 @@ BLAKEW
 BLAM
 BLANTREWI
 BLASKOV
+BLAST
 BLBLACK
 BLCKSMTH
 BLGL
@@ -1595,6 +1611,7 @@ CHAITANYA
 CHALL
 CHAMAS
 CHANG_LIU
+CHANKEY
 CHANSEN
 CHAOS
 CHAOSLAW
@@ -1742,6 +1759,7 @@ CLIVE
 CLKAO
 CLMS
 CLMSYJEDI
+CLOK
 CLONE
 CLOOS
 CLOTHO
@@ -1873,6 +1891,7 @@ CPJL
 CPK
 CPKOIS
 CPLEE
+CPORTMAN
 CPWILLMOT
 CRABTREE
 CRACKCELL
@@ -1896,6 +1915,7 @@ CRIACOW
 CRISB
 CRITICRE
 CRITTER
+CRLYJEP
 CROMEDOME
 CROMIS
 CRONUS
@@ -2168,6 +2188,7 @@ DCOLBURN
 DCOLLINS
 DCONWAY
 DCOPPIT
+DCPETROV
 DCRAWFORD
 DCREAGER
 DCS
@@ -2368,6 +2389,7 @@ DJBECKETT
 DJBERG
 DJBURKE
 DJCE
+DJCOLLINS
 DJCONNEL
 DJCP
 DJCURTIS
@@ -2650,6 +2672,7 @@ DUNCS
 DUNNIGANJ
 DUPUISARN
 DURIST
+DUSHY
 DUTCHIE
 DUTCHMAN
 DUZY
@@ -2835,6 +2858,7 @@ EMAX
 EMAZEP
 EMBIX
 EMCB
+EMEN
 EMIL
 EMILLER
 EMMANUEL
@@ -3248,6 +3272,7 @@ GBARCO
 GBARR
 GBAUER
 GBJK
+GBL
 GBOSS
 GBROCK
 GBROWN
@@ -3274,6 +3299,7 @@ GDR
 GDSL
 GEBELE
 GED
+GEEKLADY
 GEEWIZ
 GEEZENSLA
 GEEZMO
@@ -3519,6 +3545,7 @@ GUNYA
 GUOJIAN
 GURD
 GURETS
+GURUGEEK
 GURUGLENN
 GURUKUL
 GURUPERL
@@ -3609,9 +3636,11 @@ HASIOTIS
 HASSEILY
 HASTINGSE
 HATA
+HATAK
 HATENA
 HATHIPERL
 HATMAKER
+HATTORI
 HAVI
 HAVOC
 HAWAHAWAI
@@ -3619,6 +3648,7 @@ HAWK
 HAWKALOOG
 HAWKINSM
 HAWKMOON
+HAYAJO
 HAYASHI
 HAYTER
 HBABCOCK
@@ -3745,10 +3775,12 @@ HODEL
 HOEVE
 HOFFY
 HOGGARTH
+HOKKE
 HOLBROOK
 HOLGER
 HOLGILEIN
 HOLLI
+HOLLIE
 HOLLIFM
 HOLLY
 HOLLYKING
@@ -4026,6 +4058,7 @@ IWDW
 IWIARDA
 IWOODHEAD
 IX
+IXA
 IXO
 IZI
 IZUT
@@ -4557,6 +4590,7 @@ JNOBLE
 JNOLAN
 JNORUSIS
 JNPR
+JNQUINTIN
 JNSIMONN
 JNW
 JNWHITLEY
@@ -4656,6 +4690,7 @@ JOSHR
 JOSHSTEW
 JOSHUA
 JOSHUAG
+JOSHUAZ
 JOSHW
 JOST
 JOSTEN
@@ -4718,6 +4753,7 @@ JRYAN
 JSA
 JSAILOR
 JSALZ
+JSANCHEZ
 JSBARKAN
 JSCH
 JSCHNEID
@@ -4786,6 +4822,7 @@ JTURNER
 JTWEED
 JUCROUZET
 JUDD
+JUDIOO
 JUDITH
 JUDOFYR
 JUERD
@@ -4823,6 +4860,7 @@ JWALT
 JWANG
 JWAR
 JWAT
+JWAUTHIER
 JWB
 JWDOMAIN
 JWEBSTER
@@ -4890,6 +4928,7 @@ KAN
 KANE
 KANEY
 KANEZENG
+KANGELOV
 KANGU
 KANISHKA
 KANNA
@@ -5484,11 +5523,13 @@ LIOL
 LION
 LIOSHA
 LIRAZ
+LISANTRA
 LISCOVIUS
 LISPYONE
 LITCHIE
 LITERALKA
 LIUER
+LIUL
 LIWEI
 LIYANAGE
 LJOHNSON
@@ -5602,6 +5643,7 @@ LUVANTI
 LUX
 LUXOSTEIN
 LUYANFEI
+LUYSEYAL
 LVANELSEN
 LVREGENT
 LWA
@@ -5902,6 +5944,7 @@ MBARBON
 MBARTOSCH
 MBAS
 MBASOV
+MBASTOS
 MBASUNOV
 MBATISTA
 MBB
@@ -6239,6 +6282,7 @@ MKJELLMAN
 MKMUELLER
 MKODERER
 MKOSSATZ
+MKOWSIAK
 MKREBS
 MKRUSE
 MKSCHUEL
@@ -6371,6 +6415,7 @@ MOTT
 MOUNS
 MOXFYRE
 MOXNET
+MOZNION
 MOZZERB
 MPAPP
 MPASTERN
@@ -6633,6 +6678,7 @@ NATTFODD
 NATTIS
 NAUGHTON
 NAUNIDH
+NAVI
 NAVIN
 NAVNEET
 NAZAROV
@@ -6733,6 +6779,7 @@ NICWOLFF
 NICZERO
 NIDHOEGGR
 NIDS
+NIELS
 NIELSEN
 NIERLEIN
 NIERMAN
@@ -6867,6 +6914,7 @@ NWALSH
 NWCLARK
 NWELLNHOF
 NWETTERS
+NWHITEF
 NWIGER
 NWILLIAMS
 NWINT
@@ -6879,6 +6927,7 @@ NYARLA
 NYGEL
 OALDERS
 OARCHER
+OAXLIN
 OBOGREW
 OBRADOVIC
 OBULON
@@ -7146,6 +7195,7 @@ PEPE
 PEPL
 PEREINAR
 PEREZ
+PERFI
 PERFORB
 PERFORIN
 PERFSONAR
@@ -7467,6 +7517,7 @@ PTIMOF
 PTINSLEY
 PTIZOOM
 PTOMLI
+PTRS
 PTS
 PTULLY
 PUBNOOP
@@ -7805,6 +7856,7 @@ RJBS
 RJCHU
 RJE
 RJENKS
+RJESCHMI
 RJH
 RJHARMON
 RJITLA
@@ -7872,6 +7924,7 @@ RMUHLE
 RMURRI
 RMV
 RNAIMA
+RNAREN
 RNDLPH
 RNEWSHAM
 RNS
@@ -8011,6 +8064,7 @@ RTFIREFLY
 RTHANGAM
 RTHOMPSON
 RTWARD
+RTXING
 RUBINJ
 RUBLIND
 RUBYKAT
@@ -8302,6 +8356,7 @@ SEPARATOR
 SEPEHR
 SEPH
 SEPP
+SEPT
 SER
 SERA
 SERG
@@ -8661,6 +8716,7 @@ SORENSO
 SORHED
 SORO
 SORTIZ
+SOTONA
 SOURCERER
 SOVA
 SOZIN
@@ -8719,6 +8775,7 @@ SQUISH
 SRAMKI
 SRBU
 SRC
+SRCHULO
 SRDAVIS
 SREAGLE
 SREEKANTH
@@ -8726,6 +8783,7 @@ SREZIC
 SRGRN
 SRHOTON
 SRI
+SRIDHARG
 SRIEHM
 SRIHA
 SRINIK
@@ -9113,12 +9171,14 @@ TFRAYNER
 TGAETZ
 TGC
 TGIMMEL
+TGJ
 TGROSE
 TGUMMELS
 THALAKAN
 THALIANA
 THALJEF
 THAMUS
+THANGA
 THANSON
 THARDISON
 THARSCH
@@ -9517,6 +9577,7 @@ VALIANP
 VALSALAM
 VALY
 VAMSI
+VAMSIK
 VANAMBURG
 VANIX
 VANY
@@ -9634,6 +9695,7 @@ VSEGO
 VSESPB
 VSPADER
 VSSANOJ
+VSTOICAN
 VTI
 VTRONE
 VULCAN
@@ -9749,6 +9811,7 @@ WILDGOOSE
 WILIAM
 WILIV
 WILL
+WILLBELL
 WILLEM
 WILLERT
 WILLIAM
@@ -9990,6 +10053,7 @@ YORHEL
 YORICK
 YORKWU
 YOSEFM
+YOSHIAKI
 YOSHIDA
 YOSHIMI
 YOSHIOKA
@@ -10138,6 +10202,7 @@ ZOWIE
 ZOZO
 ZPMORGAN
 ZRUSILLA
+ZSC
 ZSTEVENS
 ZTANG
 ZTK
